import { EditorView, ViewUpdate, Command, KeyBinding } from "@codemirror/view";
import { Extension, TransactionSpec, Transaction, EditorState } from "@codemirror/state";
declare type Severity = "hint" | "info" | "warning" | "error";
export interface Diagnostic {
    from: number;
    to: number;
    severity: Severity;
    markClass?: string;
    source?: string;
    message: string;
    renderMessage?: (view: EditorView) => Node;
    actions?: readonly Action[];
}
export interface Action {
    name: string;
    apply: (view: EditorView, from: number, to: number) => void;
}
declare type DiagnosticFilter = (diagnostics: readonly Diagnostic[], state: EditorState) => Diagnostic[];
interface LintConfig {
    delay?: number;
    needsRefresh?: null | ((update: ViewUpdate) => boolean);
    markerFilter?: null | DiagnosticFilter;
    tooltipFilter?: null | DiagnosticFilter;
    hideOn?: (tr: Transaction, from: number, to: number) => boolean | null;
}
interface LintGutterConfig {
    hoverTime?: number;
    markerFilter?: null | DiagnosticFilter;
    tooltipFilter?: null | DiagnosticFilter;
}
export declare function setDiagnostics(state: EditorState, diagnostics: readonly Diagnostic[]): TransactionSpec;
export declare const setDiagnosticsEffect: import("@codemirror/state").StateEffectType<readonly Diagnostic[]>;
export declare function diagnosticCount(state: EditorState): number;
export declare const openLintPanel: Command;
export declare const closeLintPanel: Command;
export declare const nextDiagnostic: Command;
export declare const previousDiagnostic: Command;
export declare const lintKeymap: readonly KeyBinding[];
export declare type LintSource = (view: EditorView) => readonly Diagnostic[] | Promise<readonly Diagnostic[]>;
export declare function linter(source: LintSource | null, config?: LintConfig): Extension;
export declare function forceLinting(view: EditorView): void;
export declare function lintGutter(config?: LintGutterConfig): Extension;
export declare function forEachDiagnostic(state: EditorState, f: (d: Diagnostic, from: number, to: number) => void): void;
export {};
